#!/usr/bin/env python

# ======================================================================
# all application-global constants needed in CellDraw code are
#    placed here, for easier access from various classes
# ======================================================================


# 2010 - Mitja:
import inspect # for debugging functions, remove in final version
# debugging functions, remove in final version
def debugWhoIsTheRunningFunction():
    return inspect.stack()[1][3]
def debugWhoIsTheParentFunction():
    return inspect.stack()[2][3]


from PyQt4 import QtCore


# ----------------------------------------------------------------------
# 2011- Mitja: CDConstants doesn't do much except declare values
# ------------------------------------------------------------
class CDConstants(QtCore.QObject):
    # --------------------------------------------------------


    # 2010 - Mitja: mode for editing PIFF scene Items:
    #     (originally it was defined in the DiagramScene class as:
    #      InsertItem, InsertLine, InsertText, MoveItem  = range(4) )
    SceneModeInsertItem, SceneModeInsertLine, SceneModeInsertText, \
        SceneModeMoveItem, SceneModeInsertPixmap, SceneModeResizeItem, \
        SceneModeImageLayer = range(7)


    # 2010 - Mitja: mode for saving PIFF files, different generating methods:
    PIFFSaveWithFixedRaster, PIFFSaveWithOneRasterPerRegion, \
        PIFFSaveWithPotts = range(3)


    # 2011 - Mitja: toggle between drawing cells vs. regions,
    #    with a constant keeping track of what is to be used:
    #    0 = Cell Draw = CDConstants.ItsaCellConst
    #    1 = Region Draw = CDConstants.ItsaRegionConst
    ItsaCellConst, ItsaRegionConst  = range(2)


    # 2011 - Mitja: mode for drawing color regions and cells:
    #    1 = Color Pick = CDConstants.ImageModePickColor
    #    2 = Freehand Draw = CDConstants.ImageModeDrawFreehand
    #    3 = Polygon Draw = CDConstants.ImageModeDrawPolygon
    ImageModePickColor, ImageModeDrawFreehand, ImageModeDrawPolygon  = range(3)

    # 2011 - Mitja: debugging mode:
    #    1 = Color Pick = CDConstants.ImageModePickColor
    #    2 = Freehand Draw = CDConstants.ImageModeDrawFreehand
    #    3 = Polygon Draw = CDConstants.ImageModeDrawPolygon


    # 2011 - Mitja: debugging level:
    #    0 = DebugNone = no debug info to stderr
    #    1 = DebugSparse = some debug info
    #    2 = DebugVerbose = print out a lot of information
    #    3 = DebugExcessive = print out an excessive amount of a lot of information!
    #    4 = DebugAll = just dump everything you can
    DebugNone, DebugSparse, DebugVerbose, DebugExcessive, DebugAll = range(5)
    
    # --------------------------------------------------------
    def __init__(self, pParent=None):

        self.globalDebugLevel = CDConstants.DebugAll

        self.printOut( "DEBUG CDConstants.__init__( pParent=="+str(pParent)+" )" , CDConstants.DebugAll )

        QtCore.QObject.__init__(self, pParent)
    # end of __init__()
    # --------------------------------------------------------



    # --------------------------------------------------------
    def printOut(self, pString=None, pDebugLevel=DebugSparse):
        # example from somewhere
        # print "hello %c[1mworld%c[0m" % (27, 27)

        # only print something if pDebugLevel is high enough:
        if pDebugLevel > self.globalDebugLevel:
            return

        lYellow  = "%c[0;40;33m" % (27)
        lRed     = "%c[0;40;31m" % (27)
        lMagenta = "%c[0;40;35m" % (27)
        lBlue    = "%c[0;40;34m" % (27)
        lCyan    = "%c[0;40;36m" % (27)
        
        lEndEscSeq = "%c[0m" % (27)    # reset sequences

        if pDebugLevel == CDConstants.DebugNone:
            lStartEscSeq = lYellow        # yellow
        elif pDebugLevel == CDConstants.DebugSparse:
            lStartEscSeq = lRed           # red
        elif pDebugLevel == CDConstants.DebugVerbose:
            lStartEscSeq = lMagenta       # lMagenta
        elif pDebugLevel == CDConstants.DebugExcessive:
            lStartEscSeq = lBlue          # lBlue
        else:
            lStartEscSeq = lCyan          # lCyan

        print lStartEscSeq + pString + lEndEscSeq
    # end of printOut()
    # --------------------------------------------------------
